@@ -6,7 +6,19 @@ from staples_detection.algorithms.utils import *
 from staples_detection.base.result.canny_staple_detection_result import CannyStapleDetectionResult
 
 
-def generate_canny_mask(image: numpy.ndarray, **kwargs) -> CannyStapleDetectionResult:
+def generate_canny_mask(image: numpy.ndarray, ground_truth_mask: numpy.ndarray = None,
+                        **kwargs) -> CannyStapleDetectionResult:
+    """
+    Detects the staples in an image with a the Canny method.
+
+    Args:
+        image: A numpy array, representing the RGB image in [0, 1] range.
+        ground_truth_mask: A numpy array, representing the ground truth mask of the detection.
+        **kwargs: The parameters of the method.
+
+    Returns:
+        A CannyStapleDetectionResult object, containing the results and the elapsed time.
+    """
     # PARAMETER EXTRACTION
     gaussian_sigma: float = kwargs.get("gaussian_sigma", 1)
     lower_threshold = kwargs.get("canny_min_threshold", 100)
@@ -35,5 +47,8 @@ def generate_canny_mask(image: numpy.ndarray, **kwargs) -> CannyStapleDetectionR
 
     filtered_image = cv2.dilate(filtered_image, morphological_kernel, iterations=2)
 
-    return CannyStapleDetectionResult(filtered_image, draw_mask_over_image(image, filtered_image), time.time()-elapsed_time)
+    elapsed_time = time.time()-elapsed_time
+
+    return CannyStapleDetectionResult(filtered_image, draw_mask_over_image(image, filtered_image),
+                                      elapsed_time, ground_truth_mask)
 
